==> LoadingScreen_11-18-2018_421.zip: LoadingScreen/Intermediate/Build/Win64/UE4Editor/Development/LoadingScreen/Definitions.LoadingScreen.h <==
#undef LOADINGSCREEN_API
#undef UE_IS_ENGINE_MODULE
#undef DEPRECATED_FORGAME
#define DEPRECATED_FORGAME DEPRECATED
#define IS_PROGRAM 0
#define UE_EDITOR 1
#define ENABLE_PGO_PROFILE 0
#define WITH_DEV_AUTOMATION_TESTS 1
#define WITH_PERF_AUTOMATION_TESTS 1
#define UNICODE 1
#define _UNICODE 1
#define __UNREAL__ 1
#define IS_MONOLITHIC 0
#define WITH_ENGINE 1
#define WITH_UNREAL_DEVELOPER_TOOLS 1
#define WITH_APPLICATION_CORE 1
#define WITH_COREUOBJECT 1
#define USE_STATS_WITHOUT_ENGINE 0
#define WITH_PLUGIN_SUPPORT 0
#define WITH_PERFCOUNTERS 1
#define USE_LOGGING_IN_SHIPPING 0
#define WITH_LOGGING_TO_MEMORY 0
#define USE_CACHE_FREED_OS_ALLOCS 1
#define USE_CHECKS_IN_SHIPPING 0
#define UE_BUILD_MINIMAL 0
#define WITH_EDITOR 1
#define WITH_SERVER_CODE 1
#define WITH_CEF3 1
#define WITH_XGE_CONTROLLER 1
#define UBT_MODULE_MANIFEST "UE4Editor.modules"
#define UBT_MODULE_MANIFEST_DEBUGGAME "UE4Editor-Win64-DebugGame.modules"
#define UBT_COMPILED_PLATFORM Win64
#define UBT_COMPILED_TARGET Editor
#define UE_APP_NAME "UE4Editor"
#define WIN32 1
#define _WIN32_WINNT 0x0601
#define WINVER 0x0601
#define PLATFORM_WINDOWS 1
#define DEPTH_32_BIT_CONVERSION 0
#define NDEBUG 1
#define UE_BUILD_DEVELOPMENT 1
#define ORIGINAL_FILE_NAME "UE4Editor-LoadingScreen.dll"
#define UE_IS_ENGINE_MODULE 0
#define UE_PROJECT_NAME CardinalMenu
#define IMPLEMENT_ENCRYPTION_KEY_REGISTRATION() 
#define IMPLEMENT_SIGNING_KEY_REGISTRATION() 
#define DEPRECATED_FORGAME DEPRECATED
#define LOADINGSCREEN_API DLLEXPORT
#define UE_ENABLE_ICU 1
#define WITH_VS_PERF_PROFILER 0
#define WITH_DIRECTXMATH 0
#define WITH_MALLOC_STOMP 1
#define CORE_API DLLIMPORT
#define COREUOBJECT_API DLLIMPORT
#define MOVIEPLAYER_API DLLIMPORT
#define INCLUDE_APEIRON 0
#define WITH_PHYSX 1
#define WITH_APEIRON 0
#define PHYSICS_INTERFACE_LLIMMEDIATE 0
#define PHYSICS_INTERFACE_PHYSX 1
#define WITH_APEX 1
#define WITH_APEX_CLOTHING 1
#define WITH_CLOTH_COLLISION_DETECTION 1
#define WITH_PHYSX_COOKING 1
#define WITH_NVCLOTH 1
#define WITH_IMMEDIATE_PHYSX 0
#define GPUPARTICLE_LOCAL_VF_ONLY 0
#define ENGINE_API DLLIMPORT
#define APPLICATIONCORE_API DLLIMPORT
#define RHI_API DLLIMPORT
#define JSON_API DLLIMPORT
#define SLATE_PARENT_POINTERS 1
#define WITH_FREETYPE 1
#define SLATECORE_API DLLIMPORT
#define INPUTCORE_API DLLIMPORT
#define SLATE_API DLLIMPORT
#define WITH_UNREALPNG 1
#define WITH_UNREALJPEG 1
#define WITH_UNREALEXR 1
#define IMAGEWRAPPER_API DLLIMPORT
#define MESSAGING_API DLLIMPORT
#define MESSAGINGCOMMON_API DLLIMPORT
#define RENDERCORE_API DLLIMPORT
#define SHADERCORE_API DLLIMPORT
#define SOCKETS_PACKAGE 1
#define SOCKETS_API DLLIMPORT
#define UTILITYSHADERS_API DLLIMPORT
#define ASSETREGISTRY_API DLLIMPORT
#define ENGINEMESSAGES_API DLLIMPORT
#define ENGINESETTINGS_API DLLIMPORT
#define SYNTHBENCHMARK_API DLLIMPORT
#define RENDERER_API DLLIMPORT
#define GAMEPLAYTAGS_API DLLIMPORT
#define DATABASESUPPORT_API DLLIMPORT
#define PACKETHANDLER_API DLLIMPORT
#define RELIABILITYHANDLERCOMPONENT_API DLLIMPORT
#define AUDIOPLATFORMCONFIGURATION_API DLLIMPORT
#define MESHDESCRIPTION_API DLLIMPORT
#define PAKFILE_API DLLIMPORT
#define INCLUDE_APEIRON 0
#define WITH_PHYSX 1
#define WITH_APEIRON 0
#define PHYSICS_INTERFACE_LLIMMEDIATE 0
#define PHYSICS_INTERFACE_PHYSX 1
#define WITH_APEX 1
#define WITH_APEX_CLOTHING 1
#define WITH_CLOTH_COLLISION_DETECTION 1
#define WITH_PHYSX_COOKING 1
#define WITH_NVCLOTH 1
#define WITH_IMMEDIATE_PHYSX 0
#define WITH_RECAST 1
#define UNREALED_API DLLIMPORT
#define BSPMODE_API DLLIMPORT
#define DIRECTORYWATCHER_API DLLIMPORT
#define DOCUMENTATION_API DLLIMPORT
#define LOAD_PLUGINS_FOR_TARGET_PLATFORMS 1
#define PROJECTS_API DLLIMPORT
#define SANDBOXFILE_API DLLIMPORT
#define EDITORSTYLE_API DLLIMPORT
#define SOURCE_CONTROL_WITH_SLATE 1
#define SOURCECONTROL_API DLLIMPORT
#define UNREALEDMESSAGES_API DLLIMPORT
#define GAMEPLAYDEBUGGER_API DLLIMPORT
#define BLUEPRINTGRAPH_API DLLIMPORT
#define HTTP_PACKAGE 1
#define CURL_ENABLE_DEBUG_CALLBACK 1
#define CURL_ENABLE_NO_TIMEOUTS_OPTION 1
#define HTTP_API DLLIMPORT
#define UNREALAUDIO_API DLLIMPORT
#define FUNCTIONALTESTING_API DLLIMPORT
#define AUTOMATIONCONTROLLER_API DLLIMPORT
#define LOCALIZATION_API DLLIMPORT
#define AUDIOEDITOR_API DLLIMPORT
#define LEVELEDITOR_API DLLIMPORT
#define SETTINGS_API DLLIMPORT
#define INTROTUTORIALS_API DLLIMPORT
#define HEADMOUNTEDDISPLAY_API DLLIMPORT
#define VREDITOR_API DLLIMPORT
#define COMMONMENUEXTENSIONS_API DLLIMPORT
#define INCLUDE_APEIRON 0
#define WITH_PHYSX 1
#define WITH_APEIRON 0
#define PHYSICS_INTERFACE_LLIMMEDIATE 0
#define PHYSICS_INTERFACE_PHYSX 1
#define WITH_APEX 1
#define WITH_APEX_CLOTHING 1
#define WITH_CLOTH_COLLISION_DETECTION 1
#define WITH_PHYSX_COOKING 1
#define WITH_NVCLOTH 1
#define WITH_IMMEDIATE_PHYSX 0
#define LANDSCAPE_API DLLIMPORT
#define PROPERTYEDITOR_API DLLIMPORT
#define ACTORPICKERMODE_API DLLIMPORT
#define SCENEDEPTHPICKERMODE_API DLLIMPORT
#define DETAILCUSTOMIZATIONS_API DLLIMPORT
#define CLASSVIEWER_API DLLIMPORT
#define GRAPHEDITOR_API DLLIMPORT
#define CONTENTBROWSER_API DLLIMPORT
#define ENABLE_HTTP_FOR_NFS 1
#define NETWORKFILESYSTEM_API DLLIMPORT
#define UMG_API DLLIMPORT
#define MOVIESCENE_API DLLIMPORT
#define TIMEMANAGEMENT_API DLLIMPORT
#define MOVIESCENETRACKS_API DLLIMPORT
#define ANIMATIONCORE_API DLLIMPORT
#define PROPERTYPATH_API DLLIMPORT
#define INCLUDE_APEIRON 0
#define WITH_PHYSX 1
#define WITH_APEIRON 0
#define PHYSICS_INTERFACE_LLIMMEDIATE 0
#define PHYSICS_INTERFACE_PHYSX 1
#define WITH_APEX 1
#define WITH_APEX_CLOTHING 1
#define WITH_CLOTH_COLLISION_DETECTION 1
#define WITH_PHYSX_COOKING 1
#define WITH_NVCLOTH 1
#define WITH_IMMEDIATE_PHYSX 0
#define WITH_RECAST 1
#define NAVIGATIONSYSTEM_API DLLIMPORT
#define MESHBUILDER_API DLLIMPORT
#define MATERIALSHADERQUALITYSETTINGS_API DLLIMPORT
#define WITH_OGGVORBIS 1
#define XAUDIO2_API DLLIMPORT
#define AUDIOMIXERXAUDIO2_API DLLIMPORT
#define COLLECTIONMANAGER_API DLLIMPORT
#define ADDCONTENTDIALOG_API DLLIMPORT
#define USE_EMBREE 1
#define MESHUTILITIES_API DLLIMPORT
#define MESHMERGEUTILITIES_API DLLIMPORT
#define HIERARCHICALLODUTILITIES_API DLLIMPORT
#define MESHREDUCTIONINTERFACE_API DLLIMPORT
#define ASSETTOOLS_API DLLIMPORT
#define KISMETCOMPILER_API DLLIMPORT
#define GAMEPLAYTASKS_API DLLIMPORT
#define WITH_RECAST 1
#define WITH_GAMEPLAY_DEBUGGER 1
#define AIMODULE_API DLLIMPORT
#define KISMET_API DLLIMPORT
#define CLOTHINGSYSTEMRUNTIMEINTERFACE_API DLLIMPORT
#define NETWORKREPLAYSTREAMING_API DLLIMPORT
#define AUDIOMIXER_API DLLIMPORT
#define UELIBSAMPLERATE_API DLLIMPORT

==> LoadingScreen_12-23-2017_418.zip: LoadingScreen/Intermediate/Build/Win64/UE4Editor/Development/LoadingScreen/Definitions.LoadingScreen.h <==
#undef LOADINGSCREEN_API
#undef UE_IS_ENGINE_MODULE
#undef DEPRECATED_FORGAME
#define DEPRECATED_FORGAME DEPRECATED
#define IS_PROGRAM 0
#define UE_EDITOR 1
#define WITH_DEV_AUTOMATION_TESTS 1
#define WITH_PERF_AUTOMATION_TESTS 1
#define UNICODE 1
#define _UNICODE 1
#define __UNREAL__ 1
#define IS_MONOLITHIC 0
#define WITH_ENGINE 1
#define WITH_UNREAL_DEVELOPER_TOOLS 1
#define WITH_COREUOBJECT 1
#define USE_STATS_WITHOUT_ENGINE 0
#define WITH_PLUGIN_SUPPORT 0
#define WITH_PERFCOUNTERS 1
#define USE_LOGGING_IN_SHIPPING 0
#define WITH_LOGGING_TO_MEMORY 0
#define USE_CACHE_FREED_OS_ALLOCS 1
#define USE_CHECKS_IN_SHIPPING 0
#define UE_BUILD_MINIMAL 0
#define WITH_EDITOR 1
#define WITH_SERVER_CODE 1
#define WITH_CEF3 1
#define WITH_XGE_CONTROLLER 1
#define UBT_COMPILED_PLATFORM Win64
#define UBT_COMPILED_TARGET Editor
#define WIN32 1
#define _WIN32_WINNT 0x0601
#define WINVER 0x0601
#define PLATFORM_WINDOWS 1
#define DEPTH_32_BIT_CONVERSION 0
#define NDEBUG 1
#define UE_BUILD_DEVELOPMENT 1
#define ORIGINAL_FILE_NAME "UE4Editor-LoadingScreen.dll"
#define UE_IS_ENGINE_MODULE 0
#define UE_BUILD_DEVELOPMENT_WITH_DEBUGGAME 0
#define UE_PROJECT_NAME CardinalMenu
#define DEPRECATED_FORGAME DEPRECATED
#define LOADINGSCREEN_API DLLEXPORT
#define UE_ENABLE_ICU 1
#define WITH_VS_PERF_PROFILER 0
#define WITH_DIRECTXMATH 0
#define CORE_API DLLIMPORT
#define COREUOBJECT_API DLLIMPORT
#define MOVIEPLAYER_API DLLIMPORT
#define WITH_PHYSX 1
#define WITH_APEX 1
#define WITH_APEX_CLOTHING 1
#define WITH_CLOTH_COLLISION_DETECTION 1
#define WITH_PHYSX_COOKING 1
#define WITH_NVCLOTH 1
#define WITH_RECAST 1
#define ENGINE_API DLLIMPORT
#define APPLICATIONCORE_API DLLIMPORT
#define RHI_API DLLIMPORT
#define JSON_API DLLIMPORT
#define SLATE_DEFERRED_DESIRED_SIZE 0
#define WITH_FREETYPE 1
#define SLATECORE_API DLLIMPORT
#define INPUTCORE_API DLLIMPORT
#define SLATE_API DLLIMPORT
#define WITH_UNREALPNG 1
#define WITH_UNREALJPEG 1
#define WITH_UNREALEXR 1
#define IMAGEWRAPPER_API DLLIMPORT
#define MESSAGINGCOMMON_API DLLIMPORT
#define MESSAGING_API 
#define RENDERCORE_API DLLIMPORT
#define SHADERCORE_API DLLIMPORT
#define UTILITYSHADERS_API DLLIMPORT
#define ASSETREGISTRY_API DLLIMPORT
#define ENGINEMESSAGES_API DLLIMPORT
#define ENGINESETTINGS_API DLLIMPORT
#define SYNTHBENCHMARK_API DLLIMPORT
#define RENDERER_API 
#define GAMEPLAYTAGS_API DLLIMPORT
#define WITH_RECAST 1
#define WITH_GAMEPLAY_DEBUGGER 1
#define AIMODULE_API DLLIMPORT
#define GAMEPLAYTASKS_API DLLIMPORT
#define DATABASESUPPORT_API DLLIMPORT
#define PACKETHANDLER_API DLLIMPORT
#define RELIABILITYHANDLERCOMPONENT_API DLLIMPORT
#define HARDWARESURVEY_API DLLIMPORT
#define WITH_PHYSX 1
#define WITH_APEX 1
#define WITH_APEX_CLOTHING 1
#define WITH_CLOTH_COLLISION_DETECTION 1
#define WITH_PHYSX_COOKING 1
#define WITH_NVCLOTH 1
#define WITH_RECAST 1
#define UNREALED_API DLLIMPORT
#define BSPMODE_API DLLIMPORT
#define DIRECTORYWATCHER_API DLLIMPORT
#define DOCUMENTATION_API DLLIMPORT
#define LOAD_PLUGINS_FOR_TARGET_PLATFORMS 1
#define PROJECTS_API DLLIMPORT
#define SANDBOXFILE_API DLLIMPORT
#define EDITORSTYLE_API DLLIMPORT
#define SOURCE_CONTROL_WITH_SLATE 1
#define SOURCECONTROL_API DLLIMPORT
#define UNREALEDMESSAGES_API DLLIMPORT
#define GAMEPLAYDEBUGGER_API DLLIMPORT
#define BLUEPRINTGRAPH_API DLLIMPORT
#define HTTP_PACKAGE 1
#define HTTP_API DLLIMPORT
#define UNREALAUDIO_API DLLIMPORT
#define FUNCTIONALTESTING_API DLLIMPORT
#define AUTOMATIONCONTROLLER_API DLLIMPORT
#define LOCALIZATION_API DLLIMPORT
#define AUDIOEDITOR_API DLLIMPORT
#define LEVELEDITOR_API DLLIMPORT
#define SETTINGS_API 
#define INTROTUTORIALS_API 
#define HEADMOUNTEDDISPLAY_API 
#define VREDITOR_API 
#define WITH_PHYSX 1
#define WITH_APEX 1
#define WITH_APEX_CLOTHING 1
#define WITH_CLOTH_COLLISION_DETECTION 1
#define WITH_PHYSX_COOKING 1
#define WITH_NVCLOTH 1
#define LANDSCAPE_API DLLIMPORT
#define PROPERTYEDITOR_API DLLIMPORT
#define ACTORPICKERMODE_API DLLIMPORT
#define SCENEDEPTHPICKERMODE_API DLLIMPORT
#define DETAILCUSTOMIZATIONS_API DLLIMPORT
#define CLASSVIEWER_API DLLIMPORT
#define GRAPHEDITOR_API DLLIMPORT
#define CONTENTBROWSER_API DLLIMPORT
#define ENABLE_HTTP_FOR_NFS 1
#define NETWORKFILESYSTEM_API DLLIMPORT
#define SOCKETS_PACKAGE 1
#define SOCKETS_API DLLIMPORT
#define UMG_API DLLIMPORT
#define MOVIESCENE_API DLLIMPORT
#define MOVIESCENETRACKS_API DLLIMPORT
#define WITH_OGGVORBIS 1
#define XAUDIO2_API DLLIMPORT
#define AUDIOMIXERXAUDIO2_API DLLIMPORT
#define COLLECTIONMANAGER_API 
#define ADDCONTENTDIALOG_API 
#define USE_EMBREE 1
#define MESHUTILITIES_API 
#define MESHMERGEUTILITIES_API 
#define HIERARCHICALLODUTILITIES_API 
#define MESHREDUCTIONINTERFACE_API 
#define ASSETTOOLS_API 
#define KISMETCOMPILER_API 
#define KISMET_API DLLIMPORT
#define CLOTHINGSYSTEMRUNTIMEINTERFACE_API DLLIMPORT
#define NETWORKREPLAYSTREAMING_API 
#define AUDIOMIXER_API
